(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     26942,        527]
NotebookOptionsPosition[     26367,        505]
NotebookOutlinePosition[     26713,        520]
CellTagsIndexPosition[     26670,        517]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{
 RowBox[{
  RowBox[{"V0", "=", "2.3*^-3"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Initial", " ", "volume", " ", "of", " ", "protein", " ", "solution"}], 
    ",", " ", "L"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Alb0", "=", "1*^-6"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Concentration", " ", "of", " ", "protein", " ", "solution"}], 
    ",", " ", "M"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L0", "=", "4.6*^-5"}], 
  RowBox[{"(*", 
   RowBox[{"Concentration", " ", "of", " ", "titrant", " ", 
    RowBox[{"(", 
     RowBox[{"ligand", " ", "solution"}], ")"}]}], "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vadd", "=", "0.01*^-3"}], 
  RowBox[{"(*", 
   RowBox[{
   "Volume", " ", "of", " ", "titrant", " ", "added", " ", "per", " ", "step",
     " ", 
    RowBox[{"(", "injection", ")"}]}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numadd", "=", "10"}], 
  RowBox[{"(*", 
   RowBox[{"Number", " ", "of", " ", "steps"}], "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"conc0", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Alb0", "*", 
        RowBox[{"V0", "/", 
         RowBox[{"(", 
          RowBox[{"V0", "+", 
           RowBox[{"Vadd", "*", "n"}]}], ")"}]}]}], ",", 
       RowBox[{"L0", "*", "Vadd", "*", 
        RowBox[{"n", "/", 
         RowBox[{"(", 
          RowBox[{"V0", "+", 
           RowBox[{"Vadd", "*", "n"}]}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "numadd"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"K", "=", "8.1*^4"}], 
  RowBox[{"(*", 
   RowBox[{"True", " ", "binding", " ", "constant"}], "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"conc", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Values", "[", 
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"conc0", "[", 
              RowBox[{"[", 
               RowBox[{"n", ",", "1"}], "]"}], "]"}], "==", 
             RowBox[{"Alb", "*", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"K", "*", "L"}]}], ")"}]}]}], "&&", 
            RowBox[{
             RowBox[{"conc0", "[", 
              RowBox[{"[", 
               RowBox[{"n", ",", "2"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"L", "*", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"Alb", "*", "K"}]}], ")"}]}]}], "&&", 
            RowBox[{"Alb", "\[GreaterEqual]", "0"}], "&&", 
            RowBox[{"L", "\[GreaterEqual]", "0"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"Alb", ",", "L"}], "}"}], ",", " ", "Reals"}], "]"}], 
         "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"numadd", "+", "1"}]}], "}"}]}], "]"}], ",", "2"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eps", "=", "0"}], 
  RowBox[{"(*", 
   RowBox[{
   "Residual", " ", "fluorescence", " ", "of", " ", "complex", " ", 
    "relatively", " ", "to", " ", "the", " ", "free", " ", "protein"}], 
   "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"conc", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}], "+", 
     RowBox[{"eps", "*", "K", "*", 
      RowBox[{"conc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1"}], "]"}], "]"}], "*", 
      RowBox[{"conc", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2"}], "]"}], "]"}]}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"stern", "=", 
   RowBox[{
    StyleBox["Transpose", "Input"], 
    StyleBox["[", "Input"], 
    RowBox[{
     StyleBox["{", "Input"], 
     RowBox[{
      RowBox[{"conc0", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"conc0", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}], "/", "F"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", 
   StyleBox["[", "Input"], 
   StyleBox["stern", "Input"], 
   StyleBox["]", "Input"]}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Generates", " ", "a", " ", "Stern"}], "-", 
    RowBox[{"Volmer", " ", "plot"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lm", "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"LinearModelFit", "[", 
     RowBox[{"stern", ",", "x", ",", "x"}], "]"}], "]"}]}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Returns", " ", "fitted", " ", "Stern"}], "-", 
    RowBox[{
    "Volmer", " ", "equation", " ", "including", " ", "apparent", " ", 
     "binding", " ", "constant", " ", "value"}]}], 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6625615252340326`*^9, 3.662561554983285*^9}, {
   3.662561747456423*^9, 3.6625617792180786`*^9}, {3.662561909774708*^9, 
   3.6625619630644016`*^9}, {3.6625621511455317`*^9, 3.662562171628368*^9}, {
   3.662562225730263*^9, 3.662562256711918*^9}, {3.6625622985043907`*^9, 
   3.6625622993779926`*^9}, {3.662562390029752*^9, 3.6625624308550234`*^9}, {
   3.6625626086033535`*^9, 3.6625626254513173`*^9}, {3.6625626976880064`*^9, 
   3.662562720495247*^9}, {3.6625627824273553`*^9, 3.662562903511568*^9}, 
   3.6625629806381035`*^9, {3.662563058638241*^9, 3.6625630598550425`*^9}, {
   3.6625631011795154`*^9, 3.662563102021917*^9}, {3.6625637389866357`*^9, 
   3.662563742169041*^9}, {3.662563829809995*^9, 3.6625638307303967`*^9}, {
   3.662564005232303*^9, 3.662564038616362*^9}, {3.662564095962063*^9, 
   3.662564245191925*^9}, {3.662564608625763*^9, 3.662564617845379*^9}, {
   3.6625646548954444`*^9, 3.6625646752378798`*^9}, {3.6625647162815523`*^9, 
   3.6625647317255793`*^9}, {3.662564997819868*^9, 3.6625649997959814`*^9}, {
   3.6625651026685457`*^9, 3.6625651823222857`*^9}, {3.662565249402404*^9, 
   3.6625653313971477`*^9}, {3.6625653739852223`*^9, 
   3.6625654453241477`*^9}, {3.6625654883490233`*^9, 3.662565498239441*^9}, {
   3.662565573431573*^9, 3.6625655755375767`*^9}, {3.6625657185898275`*^9, 
   3.662565744922674*^9}, {3.6625657895543523`*^9, 3.6625657902719536`*^9}, {
   3.6625660296884274`*^9, 3.662566055054072*^9}, {3.662566086238527*^9, 
   3.6625661039601583`*^9}, {3.662566180228692*^9, 3.662566182116295*^9}, {
   3.6625662168887563`*^9, 3.662566251505217*^9}, {3.6625663038589087`*^9, 
   3.6625663052941113`*^9}, {3.6625667718597307`*^9, 
   3.6625667795973444`*^9}, {3.662566857176281*^9, 3.6625668671758986`*^9}, {
   3.662566907548769*^9, 3.662566916393985*^9}, {3.6625673356753902`*^9, 
   3.662567371196422*^9}, {3.662567430790523*^9, 3.6625674356889315`*^9}, {
   3.662567569552767*^9, 3.662567571752371*^9}, {3.6625676288172708`*^9, 
   3.66256763412128*^9}, {3.6625677504974847`*^9, 3.662567754054291*^9}, {
   3.662567908260562*^9, 3.662567911692568*^9}, {3.6625679547954435`*^9, 
   3.6625679582274494`*^9}, {3.662567996572317*^9, 3.662568016696352*^9}, {
   3.662568089049279*^9, 3.6625681694830203`*^9}, 3.6625682219303126`*^9, {
   3.662568268106394*^9, 3.662568268761595*^9}, 3.6625683318647056`*^9, {
   3.6625684072908382`*^9, 3.662568409038041*^9}, {3.6625684474453087`*^9, 
   3.6625684478197093`*^9}, {3.662568491484186*^9, 3.6625685253050456`*^9}, 
   3.6625685707635255`*^9, {3.6625686010431786`*^9, 3.6625686456436567`*^9}, {
   3.6625687451250315`*^9, 3.662568761707861*^9}, {3.6625688014723306`*^9, 
   3.6625688407531996`*^9}, {3.662568928674954*^9, 3.6625689465369854`*^9}, {
   3.662569723447977*^9, 3.6625697245711794`*^9}, {3.662569776893671*^9, 
   3.66256983289777*^9}, {3.662569882022256*^9, 3.6625699871976404`*^9}, {
   3.662570018288495*^9, 3.6625701052430477`*^9}, {3.66257014625552*^9, 
   3.662570159281543*^9}, {3.662571200645278*^9, 3.66257130436986*^9}, {
   3.66257134655358*^9, 3.662571460297804*^9}, {3.6625720166928844`*^9, 
   3.6625720249303555`*^9}, {3.6625720674624767`*^9, 3.662572265723225*^9}, {
   3.662572306033696*^9, 3.6625725696429586`*^9}, {3.66257266155832*^9, 
   3.6625727270316353`*^9}, {3.662572805437373*^9, 3.6625728313178186`*^9}, {
   3.662572964588853*^9, 3.662573073991845*^9}, {3.6625731262831364`*^9, 
   3.6625731745496216`*^9}, {3.6625732217865047`*^9, 3.662573223393307*^9}, {
   3.6625732631889772`*^9, 3.662573294669832*^9}, {3.6625735314782486`*^9, 
   3.662573581835137*^9}, {3.6625736496172557`*^9, 3.662573679912509*^9}, 
   3.662729047786069*^9, {3.66272911065845*^9, 3.6627291537029123`*^9}, {
   3.662729184825898*^9, 3.662729193905114*^9}, {3.662729246820407*^9, 
   3.662729272856853*^9}, {3.6627293300933533`*^9, 3.6627294241303186`*^9}, {
   3.6627296210650644`*^9, 3.6627296494415145`*^9}, 3.6627296800331683`*^9, 
   3.6627297102348213`*^9, {3.6627298251290236`*^9, 3.6627298384046464`*^9}, {
   3.6627298691835003`*^9, 3.662729893425943*^9}, 3.6627299257023993`*^9, {
   3.662730951018362*^9, 3.662730999050846*^9}, {3.6627310548365445`*^9, 
   3.6627310713257737`*^9}, {3.662731109811041*^9, 3.6627311687635446`*^9}, {
   3.6627313029237804`*^9, 3.6627314012663527`*^9}, {3.66273212564155*^9, 
   3.662732160351611*^9}, {3.6627322245145235`*^9, 3.662732231940137*^9}, {
   3.6627323348223176`*^9, 3.6627323765835905`*^9}, {3.6627324206848683`*^9, 
   3.6627324710105567`*^9}, {3.66273250133701*^9, 3.662732604468791*^9}, 
   3.662732642610858*^9, 3.662732727615408*^9, {3.6627327829487047`*^9, 
   3.6627329253925548`*^9}, {3.6627329610854177`*^9, 3.6627330307083397`*^9}, 
   3.662733063015997*^9, {3.6627341439634843`*^9, 3.6627341509678965`*^9}, {
   3.6627344366043987`*^9, 3.6627345526686025`*^9}, 3.662734754438266*^9, {
   3.66273479569203*^9, 3.6627348255504827`*^9}, {3.662735972087577*^9, 
   3.6627360232046185`*^9}, {3.662736068569498*^9, 3.662736072672305*^9}, {
   3.6627361400332236`*^9, 3.6627361443076315`*^9}, {3.662736334050764*^9, 
   3.662736339105173*^9}, 3.662736396575674*^9, {3.662736435513343*^9, 
   3.6627364382121477`*^9}, 3.662736472797408*^9, 3.662736579977506*^9, 
   3.6627366119723363`*^9, {3.6627366688862667`*^9, 3.6627367056243305`*^9}, {
   3.6627367356543837`*^9, 3.6627367537816153`*^9}, 3.6627369451159515`*^9, {
   3.6627371435639*^9, 3.662737144702702*^9}, {3.662737210332017*^9, 
   3.662737449887038*^9}, 3.6627374892771072`*^9, {3.662738201138134*^9, 
   3.6627382314021873`*^9}, {3.662738291821093*^9, 3.6627383410859795`*^9}, {
   3.662738391988869*^9, 3.6627384268861303`*^9}, 3.6627385947892256`*^9, {
   3.662738656253333*^9, 3.662738669716157*^9}, {3.662739381171007*^9, 
   3.66273938315221*^9}, {3.662739663765503*^9, 3.6627396697871137`*^9}, {
   3.662739959259014*^9, 3.6627400451683655`*^9}, {3.663865798062956*^9, 
   3.663865820573796*^9}, {3.6638658625846696`*^9, 3.6638658634426713`*^9}, {
   3.663865995950304*^9, 3.6638659964963045`*^9}, {3.663866076789646*^9, 
   3.6638660806584525`*^9}, {3.663866120455123*^9, 3.6638661301739397`*^9}, {
   3.663866890425675*^9, 3.663866906509303*^9}, {3.6638679456150455`*^9, 
   3.663867945911446*^9}, {3.6638679988267393`*^9, 3.6638679990607395`*^9}, {
   3.6638690553311253`*^9, 3.6638691034416094`*^9}, {3.6638691863567553`*^9, 
   3.663869204499587*^9}, {3.6638692713301044`*^9, 3.6638692718137054`*^9}, {
   3.6638695388393745`*^9, 3.66386954200618*^9}, {3.663869637556348*^9, 
   3.663869658709985*^9}, {3.66386970164126*^9, 3.663869742872133*^9}, {
   3.663869790951417*^9, 3.6638698066762447`*^9}, {3.663870002175788*^9, 
   3.6638700024565887`*^9}, {3.6638700371822495`*^9, 3.66387003741625*^9}, {
   3.6645588705872335`*^9, 3.664558898000801*^9}, {3.664558931371921*^9, 
   3.664559009918059*^9}, {3.6645593619282846`*^9, 3.664559367591095*^9}, {
   3.6645618416341476`*^9, 3.664561924267493*^9}, {3.6645619684935703`*^9, 
   3.6645619752795825`*^9}, 3.6645624083851433`*^9, {3.6645624488984146`*^9, 
   3.664562468211249*^9}, {3.6645627511049395`*^9, 3.6645627925230126`*^9}, {
   3.66456282520507*^9, 3.664562874282756*^9}, {3.6645629484920864`*^9, 
   3.6645630066333885`*^9}, {3.664635083612481*^9, 3.664635107961874*^9}, {
   3.664635148093138*^9, 3.6646352243795013`*^9}, 3.6646358909346266`*^9, {
   3.6646369896874714`*^9, 3.664636991806593*^9}, {3.6646371361668496`*^9, 
   3.6646371386529913`*^9}, {3.6646385853319607`*^9, 
   3.6646385877343645`*^9}, {3.6646457669484224`*^9, 
   3.6646457755284376`*^9}, {3.664645834262541*^9, 3.6646458852122307`*^9}, {
   3.664645954040551*^9, 3.6646459839146037`*^9}, {3.664646778571026*^9, 
   3.6646467977278595`*^9}, {3.6646468319699197`*^9, 3.66464688906602*^9}, {
   3.664646925913285*^9, 3.664647022867455*^9}, {3.664681473592984*^9, 
   3.6646814873210087`*^9}, {3.664681523528672*^9, 3.6646815830271764`*^9}, {
   3.6646817059241924`*^9, 3.6646817419144554`*^9}, {3.664682226292628*^9, 
   3.6646822400830517`*^9}, {3.664682271423507*^9, 3.664682291875143*^9}, {
   3.6646823388312254`*^9, 3.6646824242881756`*^9}, {3.6646824713534584`*^9, 
   3.6646824913682933`*^9}, {3.664683250568376*^9, 3.664683267305333*^9}, {
   3.664683300745246*^9, 3.664683313382969*^9}, {3.6646833613186035`*^9, 
   3.66468339958547*^9}, {3.664683436245535*^9, 3.6646835167572765`*^9}, {
   3.66468362140226*^9, 3.664683674988354*^9}, 3.6646837099012156`*^9, {
   3.6646838107709928`*^9, 3.6646838643882866`*^9}, {3.664683925368794*^9, 
   3.664683949673637*^9}, 3.6646848649908185`*^9, {3.664685240046677*^9, 
   3.6646853433344584`*^9}, {3.664685519926769*^9, 3.6646855736220627`*^9}, {
   3.664685751681776*^9, 3.664685766845002*^9}, {3.664685846046342*^9, 
   3.6646860102990303`*^9}, {3.664689584722481*^9, 3.664689599121306*^9}, {
   3.6646896366705723`*^9, 3.6646897527503757`*^9}, {3.664689792234045*^9, 
   3.6646898013444614`*^9}, {3.664689850266147*^9, 3.664689962274344*^9}, {
   3.6646900045972185`*^9, 3.6646900094332266`*^9}, {3.66469068407819*^9, 
   3.6646906929702053`*^9}, {3.664690782686963*^9, 3.6646907834045644`*^9}, {
   3.664690877269929*^9, 3.6646909281104183`*^9}, {3.664691132825811*^9, 
   3.664691270074897*^9}, 3.6646988667900553`*^9, {3.664698904479721*^9, 
   3.664698998189086*^9}, {3.664699169227786*^9, 3.664699185670215*^9}, {
   3.6646993678806543`*^9, 3.664699410406329*^9}, {3.664699466348027*^9, 
   3.6646994676116295`*^9}, {3.6646995393093553`*^9, 3.664699622442901*^9}, {
   3.66502852123326*^9, 3.6650285594533277`*^9}, {3.6650286286862493`*^9, 
   3.665028717434805*^9}, {3.6650287528312674`*^9, 3.6650287821437187`*^9}, {
   3.66502918098982*^9, 3.6650292103490715`*^9}, {3.6695214011765127`*^9, 
   3.6695214238448086`*^9}, 3.6695215734603662`*^9, {3.669522339542184*^9, 
   3.669522400213654*^9}, {3.6695230197972383`*^9, 3.6695230535994587`*^9}, {
   3.66952312280118*^9, 3.6695232994090877`*^9}, {3.669621078162888*^9, 
   3.669621092755723*^9}, {3.6696211228284426`*^9, 3.6696211381423187`*^9}, {
   3.6823951503489323`*^9, 3.6823951888185997`*^9}, {3.6823952304862733`*^9, 
   3.682395373335724*^9}, {3.682395415736599*^9, 3.6823955242659893`*^9}, {
   3.7681307790376244`*^9, 3.768130779297625*^9}, {3.768130836607704*^9, 
   3.7681309061248083`*^9}, 3.768130982874914*^9, {3.7906184830561113`*^9, 
   3.790618531353796*^9}, {3.790618562538251*^9, 3.790618634079976*^9}, {
   3.7906187601905975`*^9, 3.7906188212491055`*^9}, {3.790618858767171*^9, 
   3.7906189071896563`*^9}, {3.7906189860633945`*^9, 3.7906190155162463`*^9}, 
   3.790619064515932*^9, {3.7906191220176334`*^9, 3.790619141205667*^9}, {
   3.7906191829201403`*^9, 3.790619221467808*^9}, {3.7906192984539433`*^9, 
   3.790619329622798*^9}, {3.7906193628976564`*^9, 3.790619375876879*^9}, 
   3.790619532064354*^9, {3.790619594183663*^9, 3.790619607833687*^9}, {
   3.7906196743054037`*^9, 3.7906197053494577`*^9}, {3.7906197535545425`*^9, 
   3.790619805221833*^9}, {3.7906202327269845`*^9, 3.790620260635433*^9}, {
   3.7906203177325335`*^9, 3.790620362801013*^9}, {3.7906204004126787`*^9, 
   3.790620461471186*^9}, {3.790620576947589*^9, 3.7906207361468687`*^9}, {
   3.790620813378212*^9, 3.790620813674613*^9}, {3.790620867494707*^9, 
   3.7906208679471083`*^9}, {3.7906210195013742`*^9, 3.790621024618183*^9}, {
   3.7906211262055616`*^9, 3.7906211299495683`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ratnz"}], "MessageName"], ":", 
  " ", "\<\"Solve was unable to solve the system with inexact coefficients. \
The answer was obtained by solving a corresponding exact system and \
numericizing the result. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/Solve\\\", ButtonNote -> \
\\\"Solve::ratnz\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.790619124108037*^9, 3.7906191550584917`*^9, 3.790619186664147*^9, {
   3.7906193036019526`*^9, 3.7906193324464025`*^9}, 3.790619543046773*^9, {
   3.790619599066471*^9, 3.790619610423291*^9}, {3.7906196768638077`*^9, 
   3.7906197003418493`*^9}, {3.79061976907657*^9, 3.790619808201439*^9}, {
   3.790620236517791*^9, 3.790620254629423*^9}, 3.7906203658274183`*^9, {
   3.7906204023782825`*^9, 3.7906204422363524`*^9}, {3.790620585231204*^9, 
   3.7906206246066732`*^9}, {3.790620692435592*^9, 3.790620697427601*^9}, {
   3.790620732184462*^9, 3.7906207376756716`*^9}, 3.7906208902395473`*^9, 
   3.790621026178186*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ratnz"}], "MessageName"], ":", 
  " ", "\<\"Solve was unable to solve the system with inexact coefficients. \
The answer was obtained by solving a corresponding exact system and \
numericizing the result. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/Solve\\\", ButtonNote -> \
\\\"Solve::ratnz\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.790619124108037*^9, 3.7906191550584917`*^9, 3.790619186664147*^9, {
   3.7906193036019526`*^9, 3.7906193324464025`*^9}, 3.790619543046773*^9, {
   3.790619599066471*^9, 3.790619610423291*^9}, {3.7906196768638077`*^9, 
   3.7906197003418493`*^9}, {3.79061976907657*^9, 3.790619808201439*^9}, {
   3.790620236517791*^9, 3.790620254629423*^9}, 3.7906203658274183`*^9, {
   3.7906204023782825`*^9, 3.7906204422363524`*^9}, {3.790620585231204*^9, 
   3.7906206246066732`*^9}, {3.790620692435592*^9, 3.790620697427601*^9}, {
   3.790620732184462*^9, 3.7906207376756716`*^9}, 3.7906208902395473`*^9, 
   3.790621026224986*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ratnz"}], "MessageName"], ":", 
  " ", "\<\"Solve was unable to solve the system with inexact coefficients. \
The answer was obtained by solving a corresponding exact system and \
numericizing the result. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/Solve\\\", ButtonNote -> \
\\\"Solve::ratnz\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.790619124108037*^9, 3.7906191550584917`*^9, 3.790619186664147*^9, {
   3.7906193036019526`*^9, 3.7906193324464025`*^9}, 3.790619543046773*^9, {
   3.790619599066471*^9, 3.790619610423291*^9}, {3.7906196768638077`*^9, 
   3.7906197003418493`*^9}, {3.79061976907657*^9, 3.790619808201439*^9}, {
   3.790620236517791*^9, 3.790620254629423*^9}, 3.7906203658274183`*^9, {
   3.7906204023782825`*^9, 3.7906204422363524`*^9}, {3.790620585231204*^9, 
   3.7906206246066732`*^9}, {3.790620692435592*^9, 3.790620697427601*^9}, {
   3.790620732184462*^9, 3.7906207376756716`*^9}, 3.7906208902395473`*^9, 
   3.7906210262717857`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Solve :: \
ratnz\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.790619124108037*^9, 3.7906191550584917`*^9, 3.790619186664147*^9, {
   3.7906193036019526`*^9, 3.7906193324464025`*^9}, 3.790619543046773*^9, {
   3.790619599066471*^9, 3.790619610423291*^9}, {3.7906196768638077`*^9, 
   3.7906197003418493`*^9}, {3.79061976907657*^9, 3.790619808201439*^9}, {
   3.790620236517791*^9, 3.790620254629423*^9}, 3.7906203658274183`*^9, {
   3.7906204023782825`*^9, 3.7906204422363524`*^9}, {3.790620585231204*^9, 
   3.7906206246066732`*^9}, {3.790620692435592*^9, 3.790620697427601*^9}, {
   3.790620732184462*^9, 3.7906207376756716`*^9}, 3.7906208902395473`*^9, 
   3.790621026287386*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.019444444444444445`],
      AbsoluteThickness[1.6], 
     PointBox[{{0., 1.}, {1.9913419913419916`*^-7, 1.014942508667689}, {
      3.9655172413793105`*^-7, 1.0297971608283796`}, {5.92274678111588*^-7, 
      1.0445631221898024`}, {7.863247863247863*^-7, 1.0592396888366056`}, {
      9.78723404255319*^-7, 1.0738262766244508`}, {1.1694915254237287`*^-6, 
      1.0883224114094021`}, {1.3586497890295357`*^-6, 1.1027277200477055`}, {
      1.546218487394958*^-6, 1.1170419221055374`}, {1.7322175732217575`*^-6, 
      1.1312648222226207`}, {1.916666666666667*^-6, 
      1.1453963030777363`}}]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.9927301848461132},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 1.916666666666667*^-6}, {1., 1.1453963030777363`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.790619124030037*^9, 3.790619155011691*^9, 3.790619186617347*^9, {
   3.790619303539552*^9, 3.790619332618003*^9}, 3.7906195432183733`*^9, {
   3.7906195992536716`*^9, 3.7906196106104918`*^9}, {3.790619677051008*^9, 
   3.7906197005134497`*^9}, {3.79061976926377*^9, 3.7906198083886385`*^9}, {
   3.790620236689391*^9, 3.790620254816623*^9}, 3.7906203659990187`*^9, {
   3.790620402565483*^9, 3.790620442407953*^9}, {3.790620585402804*^9, 
   3.7906206247782736`*^9}, {3.7906206926071925`*^9, 3.790620697599201*^9}, {
   3.790620732371662*^9, 3.790620737862872*^9}, 3.7906208904111476`*^9, 
   3.7906210263497863`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 RowBox[{"0.9997389903171716`", "\[VeryThinSpace]", "+", 
  RowBox[{"75868.66432801515`", " ", "x"}]}]], "Output",
 CellChangeTimes->{
  3.790619124030037*^9, 3.790619155011691*^9, 3.790619186617347*^9, {
   3.790619303539552*^9, 3.790619332618003*^9}, 3.7906195432183733`*^9, {
   3.7906195992536716`*^9, 3.7906196106104918`*^9}, {3.790619677051008*^9, 
   3.7906197005134497`*^9}, {3.79061976926377*^9, 3.7906198083886385`*^9}, {
   3.790620236689391*^9, 3.790620254816623*^9}, 3.7906203659990187`*^9, {
   3.790620402565483*^9, 3.790620442407953*^9}, {3.790620585402804*^9, 
   3.7906206247782736`*^9}, {3.7906206926071925`*^9, 3.790620697599201*^9}, {
   3.790620732371662*^9, 3.790620737862872*^9}, 3.7906208904111476`*^9, 
   3.7906210263497863`*^9}]
}, Open  ]]
},
WindowSize->{1268, 958},
WindowMargins->{{Automatic, 149}, {Automatic, 6}},
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (December 4, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 16341, 303, 312, "Input"],
Cell[16924, 327, 1112, 19, 21, "Message"],
Cell[18039, 348, 1112, 19, 21, "Message"],
Cell[19154, 369, 1114, 19, 21, "Message"],
Cell[20271, 390, 1118, 19, 21, "Message"],
Cell[21392, 411, 4186, 77, 246, 1373, 31, "CachedBoxData", "BoxData", \
"Output"],
Cell[25581, 490, 770, 12, 31, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

